#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_8_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_8_HPP_INCLUDED

#include <boost/simd/constant/include/constants/oneo_8.hpp>

#endif
